==> address_suggestion-1.0.14.tar.gz: address_suggestion/src/Plugin/Field/FieldWidget/AddressSuggestionWidgetField.php <==
<?php

declare(strict_types = 1);

namespace Drupal\address_suggestion\Plugin\Field\FieldWidget;

use Drupal\address_suggestion\AddressProviderManager;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityFieldManagerInterface;
use Drupal\Core\Field\FieldConfigInterface;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines the 'address_suggestion_widget' field widget.
 *
 * @FieldWidget(
 *   id = "address_suggestion_widget",
 *   label = @Translation("Address suggestion"),
 *   field_types = {
 *     "text",
 *     "string"
 *   },
 * )
 */
final class AddressSuggestionWidgetField extends WidgetBase implements ContainerFactoryPluginInterface {

  /**
   * Constructs the plugin instance.
   */
  public function __construct(
    $plugin_id,
    $plugin_definition,
    FieldDefinitionInterface $field_definition,
    array $settings,
    array $third_party_settings,
    private readonly AddressProviderManager $addressProvider,
    private readonly ConfigFactoryInterface $configFactory,
    private readonly EntityFieldManagerInterface $entityFieldManager,
  ) {
    parent::__construct($plugin_id, $plugin_definition, $field_definition, $settings, $third_party_settings);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): self {
    return new self(
      $plugin_id,
      $plugin_definition,
      $configuration['field_definition'],
      $configuration['settings'],
      $configuration['third_party_settings'],
      $container->get('plugin.manager.address_provider'),
      $container->get('config.factory'),
      $container->get('entity_field.manager'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings(): array {
    return [
      'location_field' => '',
      'provider' => '',
      'endpoint' => '',
      'api_key' => '',
      'username' => '',
      'password' => '',
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state): array {
    $options = [];
    $entity_type = $form["#entity_type"];
    $bundle = $form["#bundle"];
    $fieldDefinitions = $this->entityFieldManager->getFieldDefinitions($entity_type, $bundle);
    $userInput = $form_state->getUserInput();
    $typSupport = ['geofield_latlon', 'geolocation_latlng'];
    if (!empty($userInput["fields"])) {
      foreach ($userInput["fields"] as $field_name => $field_widget) {
        if (!empty($field_widget['type']) &&
          in_array($field_widget['type'], $typSupport)) {
          $options[$field_name] = (string) $fieldDefinitions[$field_name]->getLabel();
        }
      }
    }
    $fieldName = $this->fieldDefinition->getName();
    $moduleSupport = ['geolocation', 'geofield'];
    if (empty($options)) {
      foreach ($fieldDefinitions as $field_name => $field_definition) {
        if ($field_definition instanceof FieldConfigInterface &&
          in_array($field_definition->getType(), $moduleSupport)) {
          $options[$field_name] = (string) $field_definition->getLabel();
        }
      }
    }
    if (!empty($options)) {
      $element['location_field'] = [
        '#type' => 'select',
        '#title' => $this->t('Location field'),
        '#default_value' => $this->getSetting('location_field'),
        '#options' => $options,
        "#empty_option" => $this->t('- Select field -'),
        "#description" => $this->t('You can attach a location field to get the coordinates'),
      ];
    }
    $endPointUrl = [
      $this->t("Fill in if you want to use your own api"),
    ];
    $options = [];
    $key = [];
    $state = [];
    $login = [];
    $addressProvider = $this->addressProvider->getDefinitions();
    foreach ($addressProvider as $provider) {
      $options[$provider['id']] = $provider['label'];
      if (!empty($provider['api'])) {
        $endPointUrl[] = $provider['label'] . ': ' . $provider['api'];
        if (!isset($provider['nokey'])) {
          $key[] = $provider['label'];
          $state[] = ['value' => $provider['id']];
        }
        if (isset($provider['login'])) {
          $login[] = ['value' => $provider['id']];
        }
      }
    }
    $element['provider'] = [
      '#type' => 'select',
      '#title' => $this->t('Provider'),
      '#default_value' => $this->getSetting('provider'),
      '#options' => $options,
      "#empty_option" => $this->t('- Select provider -'),
    ];
    $element['endpoint'] = [
      '#type' => 'url',
      '#title' => $this->t('Custom API Address endpoint'),
      '#default_value' => $this->getSetting('endpoint'),
      "#description" => implode('<br/>', $endPointUrl),
    ];
    $element['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#default_value' => $this->getSetting('api_key'),
      "#description" => $this->t('Required for provider: @key', ['@key' => implode(', ', $key)]),
      '#states' => [
        'visible' => [
          ':input[name="fields[' . $fieldName . '][settings_edit_form][settings][provider]"]' => [
            $state,
          ],
        ],
      ],
    ];
    $element['username'] = [
      '#type' => 'textfield',
      '#title' => $this->t('post.ch API username'),
      '#default_value' => $this->getSetting('username'),
      '#states' => [
        'visible' => [
          ':input[name="fields[' . $fieldName . '][settings_edit_form][settings][provider]"]' => [$login],
        ],
      ],
    ];
    $element['password'] = [
      '#type' => 'password',
      '#title' => $this->t('post.ch API password'),
      '#default_value' => $this->getSetting('password'),
      '#states' => [
        'visible' => [
          ':input[name="fields[' . $fieldName . '][settings_edit_form][settings][provider]"]' => [$login],
        ],
      ],
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary(): array {
    $summary = [];
    if (!empty($this->getSetting('location_field'))) {
      $summary[] = $this->t('Location field: @field', ['@field' => $this->getSetting('location_field')]);
    }
    if (!empty($provider = $this->getSetting('provider'))) {
      $provider = ucfirst(str_replace('_', ' ', $provider));
      $summary[] = $this->t('Provider: @provider', ['@provider' => $provider]);
    }
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state): array {
    $element['value'] = $element + [
      '#type' => 'textfield',
      '#default_value' => $items[$delta]->value ?? NULL,
    ];
    $country = $this->configFactory->get('system.date')->get('country.default');
    $fieldDefinition = $this->fieldDefinition;
    $parameters = [
      'entity_type' => $fieldDefinition->getTargetEntityTypeId(),
      'bundle' => $fieldDefinition->getTargetBundle(),
      'field_name' => $items->getName(),
    ];
    $element["value"]['#attributes']['class'][] = 'address-suggestion-widget';
    $element["value"]['#autocomplete_route_name'] = 'address_suggestion.addresses';
    $element["value"]['#autocomplete_query_parameters'] = ['country' => $country ?: FALSE];
    $element["value"]['#autocomplete_route_parameters'] = $parameters;
    $settings = $this->getSettings();
    $field_name = $this->getSetting('location_field');
    if (!empty($field_name)) {
      $fieldDefinitions = $this->entityFieldManager->getFieldDefinitions($parameters['entity_type'], $parameters['bundle']);
      $settings['type_field'] = $fieldDefinitions[$field_name]->getType();
      if (!empty($form['#parents'])) {
        $settings['location_field'] .= ']';
      }
    }
    $form['#attached']['drupalSettings']['address_suggestion'] = $settings;
    $form["#attached"]["library"][] = 'address_suggestion/address_suggestion_widget';

    return $element;
  }

}

==> address_suggestion-1.0.16.tar.gz: address_suggestion/src/Plugin/Field/FieldWidget/AddressSuggestionWidgetField.php <==
<?php

declare(strict_types = 1);

namespace Drupal\address_suggestion\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;

/**
 * Defines the 'address_suggestion_widget' field widget.
 *
 * @FieldWidget(
 *   id = "address_suggestion_widget",
 *   label = @Translation("Address suggestion"),
 *   field_types = {
 *     "text",
 *     "string"
 *   },
 * )
 */
final class AddressSuggestionWidgetField extends AddressSuggestionWidget implements ContainerFactoryPluginInterface {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state): array {
    $element['value'] = $element + [
      '#type' => 'textfield',
      '#default_value' => $items[$delta]->value ?? NULL,
    ];
    $country = $this->configFactory->get('system.date')->get('country.default');
    $fieldDefinition = $this->fieldDefinition;
    $parameters = [
      'entity_type' => $fieldDefinition->getTargetEntityTypeId(),
      'bundle' => $fieldDefinition->getTargetBundle(),
      'field_name' => $items->getName(),
    ];
    $element["value"]['#attributes']['class'][] = 'address-suggestion-widget';
    $element["value"]['#autocomplete_route_name'] = 'address_suggestion.addresses';
    $element["value"]['#autocomplete_query_parameters'] = ['country' => $country ?: FALSE];
    $element["value"]['#autocomplete_route_parameters'] = $parameters;
    $settings = $this->getSettings();
    $field_name = $this->getSetting('location_field');
    if (!empty($field_name)) {
      $entityFieldManager = \Drupal::service('entity_field.manager');
      $fieldDefinitions = $entityFieldManager->getFieldDefinitions($parameters['entity_type'], $parameters['bundle']);
      $settings['type_field'] = $fieldDefinitions[$field_name]->getType();
      if (!empty($form['#parents'])) {
        $settings['location_field'] .= ']';
      }
    }
    $form['#attached']['drupalSettings']['address_suggestion'] = $settings;
    $form["#attached"]["library"][] = 'address_suggestion/address_suggestion_widget';

    return $element;
  }

}
